@@ -16,15 +16,11 @@
 #' }
 
 plossubject <- function(q = NULL, fl = 'id', fq = NULL, sort = NULL,
-  start = 0, limit = 10,
-  sleep = 6, terms=NULL, fields=NULL, toquery=NULL, callopts=NULL, ...)
-{
-  calls <- names(sapply(match.call(), deparse))[-1]
-  calls_vec <- c("terms", "fields", "toquery", "callopts") %in% calls
-  if(any(calls_vec))
-    stop("The parameters terms, fields, toquery, and callopts replaced with q, fl, fq, ..., respectively")
+  start = 0, limit = 10, sleep = 6, errors = "simple", proxy = NULL,
+  callopts=NULL, ...) {
 
   searchplos(q=paste('subject:', '"', q, '"', sep=""), fl=fl, fq=fq,
              sort=sort, start=start, limit=limit,
-             sleep=sleep, ...)
+             sleep=sleep, errors = errors,
+             proxy = proxy, callopts = callopts, ...)
 }
